==> ejc-proequipmentcorp-impl-3.0.0-20221017.101726-8-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentMonthDetailedEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁月租明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_month_detailed")
public class RentMonthDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 设备名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="month_factory_code")
    private String monthFactoryCode; // 设备出厂编号
    @TableField(value="category_id")
    private Long categoryId; // 设备类别id
    @TableField(value="category_name")
    private String categoryName; // 设备类别名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_name")
    private String unitName; // 单位
    @TableField(value="month_rent_price")
    private BigDecimal monthRentPrice; // 日租单价
    @TableField(value="insufficient_month_day_rent_price")
    private BigDecimal insufficientMonthDayRentPrice; // 不足月日租单价
    @TableField(value="stop_rent_price")
    private BigDecimal stopRentPrice; // 停租单价
    @TableField(value="rent_num")
    private Integer rentNum; // 租赁数量
    @TableField(value="tax")
    private BigDecimal tax; // 税率
    @TableField(value="month_rent_not_tax_price")
    private BigDecimal monthRentNotTaxPrice; // 日租单价无税
    @TableField(value="insufficient_month_not_tax_rent_price")
    private BigDecimal insufficientMonthNotTaxRentPrice; // 不足月日租单价(无税)
    @TableField(value="plan_into_date")
    private Date planIntoDate; // 计划进程日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="production_manufactor")
    private String productionManufactor; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="equipment_code")
    private String equipmentCode;
    @TableField(value="equipment_id")//设备id
    private Long equipmentId;
    @TableField(value="day_tax_price")
    private BigDecimal dayTaxPrice; //含税日租单价
    @TableField(value="tax_mny")
    private BigDecimal taxMny; //含税金额
    @TableField(value="not_tax_month_price")
    private BigDecimal notTaxMonthPrice;//无税月租单价


    @TableField(value="day_rent_not_tax_price")
    private BigDecimal dayRentNotTaxPrice;
    @TableField(value="not_tax_stop_price")
    private BigDecimal notTaxStopPrice;
    @TableField(value="change_bid")
    private Long changeBid;
    @TableField(value="source_id")
    private Long sourceId;
    @TableField(value="rent_month")
    private BigDecimal rentMonth; // 租赁月数
    @TableField(value="rent_day")
    private BigDecimal rentDay; // 租赁天数
    @TableField(value="rent_mny")
    private BigDecimal rentMny; // 租赁金额(无税)
    @TableField(value="rent_tax_mny")
    private BigDecimal rentTaxMny; // 租赁金额(含税)
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 税额

    @TableField(value="change_id")
    private Long changeId;//变更子表主键
    @TableField(value="target_unit_tax_price")
    private BigDecimal targetUnitTaxPrice; //定标单价

    public BigDecimal getTargetUnitTaxPrice() {
        return targetUnitTaxPrice;
    }

    public void setTargetUnitTaxPrice(BigDecimal targetUnitTaxPrice) {
        this.targetUnitTaxPrice = targetUnitTaxPrice;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public BigDecimal getRentMonth() {
        return rentMonth;
    }

    public void setRentMonth(BigDecimal rentMonth) {
        this.rentMonth = rentMonth;
    }

    public BigDecimal getRentDay() {
        return rentDay;
    }

    public void setRentDay(BigDecimal rentDay) {
        this.rentDay = rentDay;
    }

    public BigDecimal getRentMny() {
        return rentMny;
    }

    public void setRentMny(BigDecimal rentMny) {
        this.rentMny = rentMny;
    }

    public BigDecimal getRentTaxMny() {
        return rentTaxMny;
    }

    public void setRentTaxMny(BigDecimal rentTaxMny) {
        this.rentTaxMny = rentTaxMny;
    }

    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getMonthFactoryCode() {
        return monthFactoryCode;
    }

    public void setMonthFactoryCode(String monthFactoryCode) {
        this.monthFactoryCode = monthFactoryCode;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getMonthRentPrice() {
        return monthRentPrice;
    }

    public void setMonthRentPrice(BigDecimal monthRentPrice) {
        this.monthRentPrice = monthRentPrice;
    }
    public BigDecimal getInsufficientMonthDayRentPrice() {
        return insufficientMonthDayRentPrice;
    }

    public void setInsufficientMonthDayRentPrice(BigDecimal insufficientMonthDayRentPrice) {
        this.insufficientMonthDayRentPrice = insufficientMonthDayRentPrice;
    }
    public BigDecimal getStopRentPrice() {
        return stopRentPrice;
    }

    public void setStopRentPrice(BigDecimal stopRentPrice) {
        this.stopRentPrice = stopRentPrice;
    }
    public Integer getRentNum() {
        return rentNum;
    }

    public void setRentNum(Integer rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getMonthRentNotTaxPrice() {
        return monthRentNotTaxPrice;
    }

    public void setMonthRentNotTaxPrice(BigDecimal monthRentNotTaxPrice) {
        this.monthRentNotTaxPrice = monthRentNotTaxPrice;
    }
    public BigDecimal getInsufficientMonthNotTaxRentPrice() {
        return insufficientMonthNotTaxRentPrice;
    }

    public void setInsufficientMonthNotTaxRentPrice(BigDecimal insufficientMonthNotTaxRentPrice) {
        this.insufficientMonthNotTaxRentPrice = insufficientMonthNotTaxRentPrice;
    }
    public Date getPlanIntoDate() {
        return planIntoDate;
    }

    public void setPlanIntoDate(Date planIntoDate) {
        this.planIntoDate = planIntoDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public BigDecimal getDayTaxPrice() {
        return dayTaxPrice;
    }

    public void setDayTaxPrice(BigDecimal dayTaxPrice) {
        this.dayTaxPrice = dayTaxPrice;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getNotTaxMonthPrice() {
        return notTaxMonthPrice;
    }

    public void setNotTaxMonthPrice(BigDecimal notTaxMonthPrice) {
        this.notTaxMonthPrice = notTaxMonthPrice;
    }

    public BigDecimal getDayRentNotTaxPrice() {
        return dayRentNotTaxPrice;
    }

    public void setDayRentNotTaxPrice(BigDecimal dayRentNotTaxPrice) {
        this.dayRentNotTaxPrice = dayRentNotTaxPrice;
    }

    public BigDecimal getNotTaxStopPrice() {
        return notTaxStopPrice;
    }

    public void setNotTaxStopPrice(BigDecimal notTaxStopPrice) {
        this.notTaxStopPrice = notTaxStopPrice;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentMonthDetailedEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁月租明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_month_detailed")
public class RentMonthDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 设备名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="month_factory_code")
    private String monthFactoryCode; // 设备出厂编号
    @TableField(value="category_id")
    private Long categoryId; // 设备类别id
    @TableField(value="category_name")
    private String categoryName; // 设备类别名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_name")
    private String unitName; // 单位
    @TableField(value="month_rent_price")
    private BigDecimal monthRentPrice; // 日租单价
    @TableField(value="insufficient_month_day_rent_price")
    private BigDecimal insufficientMonthDayRentPrice; // 不足月日租单价
    @TableField(value="stop_rent_price")
    private BigDecimal stopRentPrice; // 停租单价
    @TableField(value="rent_num")
    private Integer rentNum; // 租赁数量
    @TableField(value="tax")
    private BigDecimal tax; // 税率
    @TableField(value="month_rent_not_tax_price")
    private BigDecimal monthRentNotTaxPrice; // 日租单价无税
    @TableField(value="insufficient_month_not_tax_rent_price")
    private BigDecimal insufficientMonthNotTaxRentPrice; // 不足月日租单价(无税)
    @TableField(value="plan_into_date")
    private Date planIntoDate; // 计划进程日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="production_manufactor")
    private String productionManufactor; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="equipment_code")
    private String equipmentCode;
    @TableField(value="equipment_id")//设备id
    private Long equipmentId;
    @TableField(value="day_tax_price")
    private BigDecimal dayTaxPrice; //含税日租单价
    @TableField(value="tax_mny")
    private BigDecimal taxMny; //含税金额
    @TableField(value="not_tax_month_price")
    private BigDecimal notTaxMonthPrice;//无税月租单价


    @TableField(value="day_rent_not_tax_price")
    private BigDecimal dayRentNotTaxPrice;
    @TableField(value="not_tax_stop_price")
    private BigDecimal notTaxStopPrice;
    @TableField(value="change_bid")
    private Long changeBid;
    @TableField(value="source_id")
    private Long sourceId;
    @TableField(value="rent_month")
    private BigDecimal rentMonth; // 租赁月数
    @TableField(value="rent_day")
    private BigDecimal rentDay; // 租赁天数
    @TableField(value="rent_mny")
    private BigDecimal rentMny; // 租赁金额(无税)
    @TableField(value="rent_tax_mny")
    private BigDecimal rentTaxMny; // 租赁金额(含税)
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 税额

    @TableField(value="change_id")
    private Long changeId;//变更子表主键
    @TableField(value="target_unit_tax_price")
    private BigDecimal targetUnitTaxPrice; //定标单价

    @TableField(value="plan_inst_height")
    private BigDecimal planInstHeight; // 计划安装高度
    @TableField(value="plan_inst_num")
    private BigDecimal planInstNum; // 计划安装附着道数
    @TableField(value="plan_inst_location")
    private String planInstLocation; // 计划安装位置

    public BigDecimal getPlanInstHeight() {
        return planInstHeight;
    }

    public void setPlanInstHeight(BigDecimal planInstHeight) {
        this.planInstHeight = planInstHeight;
    }

    public BigDecimal getPlanInstNum() {
        return planInstNum;
    }

    public void setPlanInstNum(BigDecimal planInstNum) {
        this.planInstNum = planInstNum;
    }

    public String getPlanInstLocation() {
        return planInstLocation;
    }

    public void setPlanInstLocation(String planInstLocation) {
        this.planInstLocation = planInstLocation;
    }

    public BigDecimal getTargetUnitTaxPrice() {
        return targetUnitTaxPrice;
    }

    public void setTargetUnitTaxPrice(BigDecimal targetUnitTaxPrice) {
        this.targetUnitTaxPrice = targetUnitTaxPrice;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public BigDecimal getRentMonth() {
        return rentMonth;
    }

    public void setRentMonth(BigDecimal rentMonth) {
        this.rentMonth = rentMonth;
    }

    public BigDecimal getRentDay() {
        return rentDay;
    }

    public void setRentDay(BigDecimal rentDay) {
        this.rentDay = rentDay;
    }

    public BigDecimal getRentMny() {
        return rentMny;
    }

    public void setRentMny(BigDecimal rentMny) {
        this.rentMny = rentMny;
    }

    public BigDecimal getRentTaxMny() {
        return rentTaxMny;
    }

    public void setRentTaxMny(BigDecimal rentTaxMny) {
        this.rentTaxMny = rentTaxMny;
    }

    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getMonthFactoryCode() {
        return monthFactoryCode;
    }

    public void setMonthFactoryCode(String monthFactoryCode) {
        this.monthFactoryCode = monthFactoryCode;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getMonthRentPrice() {
        return monthRentPrice;
    }

    public void setMonthRentPrice(BigDecimal monthRentPrice) {
        this.monthRentPrice = monthRentPrice;
    }
    public BigDecimal getInsufficientMonthDayRentPrice() {
        return insufficientMonthDayRentPrice;
    }

    public void setInsufficientMonthDayRentPrice(BigDecimal insufficientMonthDayRentPrice) {
        this.insufficientMonthDayRentPrice = insufficientMonthDayRentPrice;
    }
    public BigDecimal getStopRentPrice() {
        return stopRentPrice;
    }

    public void setStopRentPrice(BigDecimal stopRentPrice) {
        this.stopRentPrice = stopRentPrice;
    }
    public Integer getRentNum() {
        return rentNum;
    }

    public void setRentNum(Integer rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getMonthRentNotTaxPrice() {
        return monthRentNotTaxPrice;
    }

    public void setMonthRentNotTaxPrice(BigDecimal monthRentNotTaxPrice) {
        this.monthRentNotTaxPrice = monthRentNotTaxPrice;
    }
    public BigDecimal getInsufficientMonthNotTaxRentPrice() {
        return insufficientMonthNotTaxRentPrice;
    }

    public void setInsufficientMonthNotTaxRentPrice(BigDecimal insufficientMonthNotTaxRentPrice) {
        this.insufficientMonthNotTaxRentPrice = insufficientMonthNotTaxRentPrice;
    }
    public Date getPlanIntoDate() {
        return planIntoDate;
    }

    public void setPlanIntoDate(Date planIntoDate) {
        this.planIntoDate = planIntoDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public BigDecimal getDayTaxPrice() {
        return dayTaxPrice;
    }

    public void setDayTaxPrice(BigDecimal dayTaxPrice) {
        this.dayTaxPrice = dayTaxPrice;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getNotTaxMonthPrice() {
        return notTaxMonthPrice;
    }

    public void setNotTaxMonthPrice(BigDecimal notTaxMonthPrice) {
        this.notTaxMonthPrice = notTaxMonthPrice;
    }

    public BigDecimal getDayRentNotTaxPrice() {
        return dayRentNotTaxPrice;
    }

    public void setDayRentNotTaxPrice(BigDecimal dayRentNotTaxPrice) {
        this.dayRentNotTaxPrice = dayRentNotTaxPrice;
    }

    public BigDecimal getNotTaxStopPrice() {
        return notTaxStopPrice;
    }

    public void setNotTaxStopPrice(BigDecimal notTaxStopPrice) {
        this.notTaxStopPrice = notTaxStopPrice;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}
